# coding: utf-8

"""
    VeeRoute.LSS Account

    LSS Account Panel  # noqa: E501

    The version of the OpenAPI document: 3.6.163551
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_account
from vrt_lss_account.models.check_result import CheckResult  # noqa: E501
from vrt_lss_account.rest import ApiException

class TestCheckResult(unittest.TestCase):
    """CheckResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CheckResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_account.models.check_result.CheckResult()  # noqa: E501
        if include_optional :
            return CheckResult(
                health = 0.9
            )
        else :
            return CheckResult(
                health = 0.9,
        )

    def testCheckResult(self):
        """Test CheckResult"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



TOKEN_TASK_SCHEMA = '''{
    "additionalProperties": false,
    "properties": {
        "password": {
            "maxLength": 1000,
            "minLength": 1,
            "type": "string"
        },
        "ttl_seconds": {
            "default": 86400,
            "format": "int32",
            "maximum": 31556926,
            "minimum": 60,
            "type": "integer"
        },
        "username": {
            "maxLength": 256,
            "minLength": 1,
            "type": "string"
        }
    },
    "required": [
        "username",
        "password"
    ],
    "type": "object"
}'''


# coding: utf-8

"""
    VeeRoute.LSS Account

    LSS Account Panel  # noqa: E501

    The version of the OpenAPI document: 3.6.163551
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_account
from vrt_lss_account.models.user_statistics import UserStatistics  # noqa: E501
from vrt_lss_account.rest import ApiException

class TestUserStatistics(unittest.TestCase):
    """UserStatistics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UserStatistics
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_account.models.user_statistics.UserStatistics()  # noqa: E501
        if include_optional :
            return UserStatistics(
                username = 'user_login', 
                dates = [
                    vrt_lss_account.models.date_statistics.DateStatistics(
                        date = 'Thu Nov 05 03:00:00 MSK 2020', 
                        services = [
                            vrt_lss_account.models.service_statistics.ServiceStatistics(
                                service = 'Lastmile', 
                                methods = [
                                    vrt_lss_account.models.method_statistics.MethodStatistics(
                                        method = 'plan', 
                                        unique_points_per_day = 1500, 
                                        points_per_day = 1500, )
                                    ], )
                            ], )
                    ]
            )
        else :
            return UserStatistics(
                username = 'user_login',
                dates = [
                    vrt_lss_account.models.date_statistics.DateStatistics(
                        date = 'Thu Nov 05 03:00:00 MSK 2020', 
                        services = [
                            vrt_lss_account.models.service_statistics.ServiceStatistics(
                                service = 'Lastmile', 
                                methods = [
                                    vrt_lss_account.models.method_statistics.MethodStatistics(
                                        method = 'plan', 
                                        unique_points_per_day = 1500, 
                                        points_per_day = 1500, )
                                    ], )
                            ], )
                    ],
        )

    def testUserStatistics(self):
        """Test UserStatistics"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



STATISTICS_TASK_SCHEMA = '''{
    "additionalProperties": false,
    "properties": {
        "date_window": {
            "additionalProperties": false,
            "properties": {
                "from": {
                    "format": "date",
                    "type": "string"
                },
                "to": {
                    "format": "date",
                    "type": "string"
                }
            },
            "required": [
                "from",
                "to"
            ],
            "type": "object"
        }
    },
    "type": "object"
}'''


# coding: utf-8

"""
    VeeRoute.LSS Account

    LSS Account Panel  # noqa: E501

    The version of the OpenAPI document: 3.6.163551
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_account
from vrt_lss_account.models.user_quota_result import UserQuotaResult  # noqa: E501
from vrt_lss_account.rest import ApiException

class TestUserQuotaResult(unittest.TestCase):
    """UserQuotaResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UserQuotaResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_account.models.user_quota_result.UserQuotaResult()  # noqa: E501
        if include_optional :
            return UserQuotaResult(
                base = vrt_lss_account.models.quota.Quota(
                    services = [
                        vrt_lss_account.models.service_quota.ServiceQuota(
                            service = 'Lastmile', 
                            methods = [
                                vrt_lss_account.models.method_quota.MethodQuota(
                                    method = 'plan', 
                                    points_per_request = 15, 
                                    points_per_day = 1500, 
                                    points_per_date_window = 1500, 
                                    max_concurrent_execution = 5, )
                                ], )
                        ], ), 
                additional = vrt_lss_account.models.additional_quota.AdditionalQuota(
                    date_window = vrt_lss_account.models.date_window.DateWindow(
                        from = 'Sat Nov 21 03:00:00 MSK 2020', 
                        to = 'Sat Nov 21 03:00:00 MSK 2020', ), 
                    quota = vrt_lss_account.models.quota.Quota(
                        services = [
                            vrt_lss_account.models.service_quota.ServiceQuota(
                                service = 'Lastmile', 
                                methods = [
                                    vrt_lss_account.models.method_quota.MethodQuota(
                                        method = 'plan', 
                                        points_per_request = 15, 
                                        points_per_day = 1500, 
                                        points_per_date_window = 1500, 
                                        max_concurrent_execution = 5, )
                                    ], )
                            ], ), )
            )
        else :
            return UserQuotaResult(
        )

    def testUserQuotaResult(self):
        """Test UserQuotaResult"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    VeeRoute.LSS Account

    LSS Account Panel  # noqa: E501

    The version of the OpenAPI document: 3.6.163551
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_lss_account.configuration import Configuration


class AccountInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'username': 'str',
        'name': 'str',
        'email': 'str',
        'phone': 'str',
        'company': 'str',
        'timezone': 'int'
    }

    attribute_map = {
        'username': 'username',
        'name': 'name',
        'email': 'email',
        'phone': 'phone',
        'company': 'company',
        'timezone': 'timezone'
    }

    def __init__(self, username=None, name=None, email=None, phone=None, company=None, timezone=0, local_vars_configuration=None):  # noqa: E501
        """AccountInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._username = None
        self._name = None
        self._email = None
        self._phone = None
        self._company = None
        self._timezone = None
        self.discriminator = None

        self.username = username
        if name is not None:
            self.name = name
        if email is not None:
            self.email = email
        if phone is not None:
            self.phone = phone
        if company is not None:
            self.company = company
        if timezone is not None:
            self.timezone = timezone

    @property
    def username(self):
        """Gets the username of this AccountInfo.  # noqa: E501

        Login, ID.  # noqa: E501

        :return: The username of this AccountInfo.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this AccountInfo.

        Login, ID.  # noqa: E501

        :param username: The username of this AccountInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and username is None:  # noqa: E501
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                username is not None and len(username) > 256):
            raise ValueError("Invalid value for `username`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                username is not None and len(username) < 1):
            raise ValueError("Invalid value for `username`, length must be greater than or equal to `1`")  # noqa: E501

        self._username = username

    @property
    def name(self):
        """Gets the name of this AccountInfo.  # noqa: E501

        Full name of user.  # noqa: E501

        :return: The name of this AccountInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AccountInfo.

        Full name of user.  # noqa: E501

        :param name: The name of this AccountInfo.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 256):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def email(self):
        """Gets the email of this AccountInfo.  # noqa: E501

        User mail address.  # noqa: E501

        :return: The email of this AccountInfo.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this AccountInfo.

        User mail address.  # noqa: E501

        :param email: The email of this AccountInfo.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                email is not None and len(email) > 256):
            raise ValueError("Invalid value for `email`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                email is not None and len(email) < 1):
            raise ValueError("Invalid value for `email`, length must be greater than or equal to `1`")  # noqa: E501

        self._email = email

    @property
    def phone(self):
        """Gets the phone of this AccountInfo.  # noqa: E501

        User phone.  # noqa: E501

        :return: The phone of this AccountInfo.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this AccountInfo.

        User phone.  # noqa: E501

        :param phone: The phone of this AccountInfo.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                phone is not None and len(phone) > 256):
            raise ValueError("Invalid value for `phone`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                phone is not None and len(phone) < 1):
            raise ValueError("Invalid value for `phone`, length must be greater than or equal to `1`")  # noqa: E501

        self._phone = phone

    @property
    def company(self):
        """Gets the company of this AccountInfo.  # noqa: E501

        Сompany.  # noqa: E501

        :return: The company of this AccountInfo.  # noqa: E501
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this AccountInfo.

        Сompany.  # noqa: E501

        :param company: The company of this AccountInfo.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                company is not None and len(company) > 256):
            raise ValueError("Invalid value for `company`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                company is not None and len(company) < 1):
            raise ValueError("Invalid value for `company`, length must be greater than or equal to `1`")  # noqa: E501

        self._company = company

    @property
    def timezone(self):
        """Gets the timezone of this AccountInfo.  # noqa: E501

        Basic time zone used for statistics.  # noqa: E501

        :return: The timezone of this AccountInfo.  # noqa: E501
        :rtype: int
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """Sets the timezone of this AccountInfo.

        Basic time zone used for statistics.  # noqa: E501

        :param timezone: The timezone of this AccountInfo.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                timezone is not None and timezone > 12):  # noqa: E501
            raise ValueError("Invalid value for `timezone`, must be a value less than or equal to `12`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                timezone is not None and timezone < -12):  # noqa: E501
            raise ValueError("Invalid value for `timezone`, must be a value greater than or equal to `-12`")  # noqa: E501

        self._timezone = timezone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccountInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    VeeRoute.LSS Account

    LSS Account Panel  # noqa: E501

    The version of the OpenAPI document: 3.6.163551
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from vrt_lss_account.configuration import Configuration


class MethodQuota(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'method': 'MethodName',
        'points_per_request': 'int',
        'points_per_day': 'int',
        'points_per_date_window': 'int',
        'max_concurrent_execution': 'int'
    }

    attribute_map = {
        'method': 'method',
        'points_per_request': 'points_per_request',
        'points_per_day': 'points_per_day',
        'points_per_date_window': 'points_per_date_window',
        'max_concurrent_execution': 'max_concurrent_execution'
    }

    def __init__(self, method=None, points_per_request=None, points_per_day=None, points_per_date_window=None, max_concurrent_execution=0, local_vars_configuration=None):  # noqa: E501
        """MethodQuota - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._method = None
        self._points_per_request = None
        self._points_per_day = None
        self._points_per_date_window = None
        self._max_concurrent_execution = None
        self.discriminator = None

        self.method = method
        self.points_per_request = points_per_request
        self.points_per_day = points_per_day
        if points_per_date_window is not None:
            self.points_per_date_window = points_per_date_window
        if max_concurrent_execution is not None:
            self.max_concurrent_execution = max_concurrent_execution

    @property
    def method(self):
        """Gets the method of this MethodQuota.  # noqa: E501


        :return: The method of this MethodQuota.  # noqa: E501
        :rtype: MethodName
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this MethodQuota.


        :param method: The method of this MethodQuota.  # noqa: E501
        :type: MethodName
        """
        if self.local_vars_configuration.client_side_validation and method is None:  # noqa: E501
            raise ValueError("Invalid value for `method`, must not be `None`")  # noqa: E501

        self._method = method

    @property
    def points_per_request(self):
        """Gets the points_per_request of this MethodQuota.  # noqa: E501

        Maximum number of non-unique points per request.  # noqa: E501

        :return: The points_per_request of this MethodQuota.  # noqa: E501
        :rtype: int
        """
        return self._points_per_request

    @points_per_request.setter
    def points_per_request(self, points_per_request):
        """Sets the points_per_request of this MethodQuota.

        Maximum number of non-unique points per request.  # noqa: E501

        :param points_per_request: The points_per_request of this MethodQuota.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and points_per_request is None:  # noqa: E501
            raise ValueError("Invalid value for `points_per_request`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                points_per_request is not None and points_per_request > 1000000):  # noqa: E501
            raise ValueError("Invalid value for `points_per_request`, must be a value less than or equal to `1000000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                points_per_request is not None and points_per_request < 0):  # noqa: E501
            raise ValueError("Invalid value for `points_per_request`, must be a value greater than or equal to `0`")  # noqa: E501

        self._points_per_request = points_per_request

    @property
    def points_per_day(self):
        """Gets the points_per_day of this MethodQuota.  # noqa: E501

        Maximum number of non-unique points per request per day.  # noqa: E501

        :return: The points_per_day of this MethodQuota.  # noqa: E501
        :rtype: int
        """
        return self._points_per_day

    @points_per_day.setter
    def points_per_day(self, points_per_day):
        """Sets the points_per_day of this MethodQuota.

        Maximum number of non-unique points per request per day.  # noqa: E501

        :param points_per_day: The points_per_day of this MethodQuota.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and points_per_day is None:  # noqa: E501
            raise ValueError("Invalid value for `points_per_day`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                points_per_day is not None and points_per_day > 100000000):  # noqa: E501
            raise ValueError("Invalid value for `points_per_day`, must be a value less than or equal to `100000000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                points_per_day is not None and points_per_day < 0):  # noqa: E501
            raise ValueError("Invalid value for `points_per_day`, must be a value greater than or equal to `0`")  # noqa: E501

        self._points_per_day = points_per_day

    @property
    def points_per_date_window(self):
        """Gets the points_per_date_window of this MethodQuota.  # noqa: E501

        The maximum total number of non-unique points for the specified time period, multiple of a day. If the time period equals to a day, this parameter is not taken into account, since it is responsible for one day   # noqa: E501

        :return: The points_per_date_window of this MethodQuota.  # noqa: E501
        :rtype: int
        """
        return self._points_per_date_window

    @points_per_date_window.setter
    def points_per_date_window(self, points_per_date_window):
        """Sets the points_per_date_window of this MethodQuota.

        The maximum total number of non-unique points for the specified time period, multiple of a day. If the time period equals to a day, this parameter is not taken into account, since it is responsible for one day   # noqa: E501

        :param points_per_date_window: The points_per_date_window of this MethodQuota.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                points_per_date_window is not None and points_per_date_window > 100000000):  # noqa: E501
            raise ValueError("Invalid value for `points_per_date_window`, must be a value less than or equal to `100000000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                points_per_date_window is not None and points_per_date_window < 0):  # noqa: E501
            raise ValueError("Invalid value for `points_per_date_window`, must be a value greater than or equal to `0`")  # noqa: E501

        self._points_per_date_window = points_per_date_window

    @property
    def max_concurrent_execution(self):
        """Gets the max_concurrent_execution of this MethodQuota.  # noqa: E501

        The maximum total number of concurrent method execution.   # noqa: E501

        :return: The max_concurrent_execution of this MethodQuota.  # noqa: E501
        :rtype: int
        """
        return self._max_concurrent_execution

    @max_concurrent_execution.setter
    def max_concurrent_execution(self, max_concurrent_execution):
        """Sets the max_concurrent_execution of this MethodQuota.

        The maximum total number of concurrent method execution.   # noqa: E501

        :param max_concurrent_execution: The max_concurrent_execution of this MethodQuota.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                max_concurrent_execution is not None and max_concurrent_execution > 1000):  # noqa: E501
            raise ValueError("Invalid value for `max_concurrent_execution`, must be a value less than or equal to `1000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                max_concurrent_execution is not None and max_concurrent_execution < 0):  # noqa: E501
            raise ValueError("Invalid value for `max_concurrent_execution`, must be a value greater than or equal to `0`")  # noqa: E501

        self._max_concurrent_execution = max_concurrent_execution

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MethodQuota):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MethodQuota):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import
from vrt_lss_account.schemes.token_task_schema import *
from vrt_lss_account.schemes.token_result_schema import *
from vrt_lss_account.schemes.statistics_task_schema import *
from vrt_lss_account.schemes.statistics_result_schema import *


STATISTICS_RESULT_SCHEMA = '''{
    "additionalProperties": false,
    "properties": {
        "dates": {
            "items": {
                "additionalProperties": false,
                "properties": {
                    "date": {
                        "format": "date",
                        "type": "string"
                    },
                    "services": {
                        "items": {
                            "additionalProperties": false,
                            "properties": {
                                "methods": {
                                    "items": {
                                        "additionalProperties": false,
                                        "properties": {
                                            "method": {
                                                "enum": [
                                                    "plan",
                                                    "convert",
                                                    "analytics",
                                                    "predict",
                                                    "actualize",
                                                    "validate",
                                                    "route",
                                                    "matrix",
                                                    "cluster"
                                                ],
                                                "type": "string"
                                            },
                                            "points_per_day": {
                                                "default": 0,
                                                "format": "int32",
                                                "maximum": 10000000,
                                                "minimum": 0,
                                                "type": "integer"
                                            },
                                            "unique_points_per_day": {
                                                "default": 0,
                                                "format": "int32",
                                                "maximum": 10000000,
                                                "minimum": 0,
                                                "type": "integer"
                                            }
                                        },
                                        "required": [
                                            "method",
                                            "unique_points_per_day",
                                            "points_per_day"
                                        ],
                                        "type": "object"
                                    },
                                    "minItems": 1,
                                    "type": "array"
                                },
                                "service": {
                                    "enum": [
                                        "Lastmile",
                                        "Delivery",
                                        "FieldService",
                                        "Merchandiser",
                                        "Routing",
                                        "Clustering",
                                        "Account",
                                        "Partner"
                                    ],
                                    "type": "string"
                                }
                            },
                            "required": [
                                "service",
                                "methods"
                            ],
                            "type": "object"
                        },
                        "minItems": 1,
                        "type": "array"
                    }
                },
                "required": [
                    "date",
                    "services"
                ],
                "type": "object"
            },
            "minItems": 1,
            "type": "array"
        },
        "username": {
            "maxLength": 256,
            "minLength": 2,
            "type": "string"
        }
    },
    "required": [
        "username",
        "dates"
    ],
    "type": "object"
}'''